"""
    QuaO Project sdk.py Copyright © CITYNOW Co. Ltd. All rights reserved.
"""
from enum import Enum


class Sdk(Enum):
    QISKIT = 'qiskit'
    BRAKET = 'braket'
    TYTAN = 'tytan'

    @staticmethod
    def resolve_sdk(sdk_type: str):
        for element in Sdk:
            if element.value.__eq__(sdk_type):
                return element

        raise Exception("sdk not supported!")



"""
    QuaO Project ProviderType.py Copyright © CITYNOW Co. Ltd. All rights reserved.
"""
from enum import Enum


class ProviderType(Enum):
    QUAO_QUANTUM_SIMULATOR = 'QUAO_QUANTUM_SIMULATOR'
    IBM_QUANTUM = 'IBM_QUANTUM'
    IBM_CLOUD = 'IBM_CLOUD'
    AWS_BRAKET = 'AWS_BRAKET'

    @staticmethod
    def resolve_provider_type(provider_type: str):
        for element in ProviderType:
            if element.value.__eq__(provider_type):
                return element

        raise Exception("provider not supported!")
